==> lsst_ctrl_bps_panda-26.2023.4600-py3-none-any.whl: lsst/ctrl/bps/panda/constants.py <==
# This file is part of ctrl_bps_panda.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""Symbolic constants
"""

PANDA_DEFAULT_PROD_SOURCE_LABEL = "managed"
PANDA_DEFAULT_PROCESSING_TYPE = None
PANDA_DEFAULT_TASK_TYPE = "test"
PANDA_DEFAULT_VO = "wlcg"
PANDA_DEFAULT_PRIORITY = 900
PANDA_DEFAULT_MAX_JOBS_PER_TASK = 30000
PANDA_DEFAULT_RSS = 1024
PANDA_DEFAULT_MAX_WALLTIME = 90000
PANDA_DEFAULT_MAX_ATTEMPTS = 3
PANDA_DEFAULT_CORE_COUNT = 1
PANDA_DEFAULT_CLOUD = "US"
PANDA_DEFAULT_MAX_COPY_WORKERS = 10

==> lsst_ctrl_bps_panda-26.2024.900-py3-none-any.whl: lsst/ctrl/bps/panda/constants.py <==
# This file is part of ctrl_bps_panda.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""Symbolic constants.
"""

PANDA_DEFAULT_PROD_SOURCE_LABEL = "managed"
PANDA_DEFAULT_PROCESSING_TYPE = None
PANDA_DEFAULT_TASK_TYPE = "test"
PANDA_DEFAULT_VO = "wlcg"
PANDA_DEFAULT_PRIORITY = 900
PANDA_DEFAULT_MAX_JOBS_PER_TASK = 30000
PANDA_DEFAULT_RSS = 1024
PANDA_DEFAULT_RSS_MAX = 512000  # 500 * 1024
PANDA_DEFAULT_MAX_WALLTIME = 90000
PANDA_DEFAULT_MAX_ATTEMPTS = 3
PANDA_DEFAULT_CORE_COUNT = 1
PANDA_DEFAULT_CLOUD = "US"
PANDA_DEFAULT_MAX_COPY_WORKERS = 10
